
![logo](images/logo.png)

Objexplore is an interactive Python object explorer for the terminal. Use it while debugging, or exploring a new library, or whatever!

![cibuild](https://github.com/kylepollina/objexplore/actions/workflows/python-app.yml/badge.svg) ![pypi](https://img.shields.io/pypi/v/objexplore.svg)


https://user-images.githubusercontent.com/13981456/133720490-7bd08dc6-4407-48f1-912a-329be6173619.mov


## Install

```
pip install objexplore
```

or

```
pip install git+https://github.com/kylepollina/objexplore
```

## Usage

```python
from objexplore import explore
import pandas
explore(pandas)
```

## Features

### Dictionary explorer

https://user-images.githubusercontent.com/13981456/133886899-ae91cc77-7b63-4e39-9cbc-197805c72f24.mov

### List/tuple explorer

https://user-images.githubusercontent.com/13981456/133889219-0b80d1f4-697a-4532-aa4a-00898267eef5.mov



## Contributing
Read [CONTRIBUTING.md](CONTRIBUTING.md)




